@@ -22,30 +22,29 @@ build_time_vars = {'ABIFLAGS': '',
  'CC': 'gcc',
  'CCSHARED': '-fPIC',
  'CFLAGS': '-Wno-unused-result -Wsign-compare -DDYNAMIC_ANNOTATIONS_ENABLED=1 '
-           '-DNDEBUG  -O2  -fexceptions -g -grecord-gcc-switches -pipe -Wall '
+           '-DNDEBUG    -fexceptions -g -grecord-gcc-switches -pipe -Wall '
            '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
            '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   '
            '-fasynchronous-unwind-tables -fstack-clash-protection '
-           '-D_GNU_SOURCE -fPIC -fwrapv -O2  -fexceptions -g '
+           '-D_GNU_SOURCE -fPIC -fwrapv -fexceptions -g -grecord-gcc-switches '
+           '-pipe -Wall -Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
+           '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   '
+           '-fasynchronous-unwind-tables -fstack-clash-protection '
+           '-D_GNU_SOURCE -fPIC -fwrapv    -fexceptions -g '
            '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
            '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS  '
            '-fstack-protector-strong   -fasynchronous-unwind-tables '
-           '-fstack-clash-protection -D_GNU_SOURCE -fPIC -fwrapv  -O2  '
-           '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
-           '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
-           '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   '
-           '-fasynchronous-unwind-tables -fstack-clash-protection '
-           '-D_GNU_SOURCE -fPIC -fwrapv',
+           '-fstack-clash-protection -D_GNU_SOURCE -fPIC -fwrapv  -O3',
  'CFLAGSFORSHARED': '-fPIC',
  'CFLAGS_ALIASING': '',
  'CONFIGFILES': 'configure configure.ac acconfig.h pyconfig.h.in '
                 'Makefile.pre.in',
- 'CONFIGURE_CFLAGS': '-O2  -fexceptions -g -grecord-gcc-switches -pipe -Wall '
+ 'CONFIGURE_CFLAGS': '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
                      '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                      '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   '
                      '-fasynchronous-unwind-tables -fstack-clash-protection '
                      '-D_GNU_SOURCE -fPIC -fwrapv',
- 'CONFIGURE_CFLAGS_NODIST': '-O2 -flto=auto -ffat-lto-objects -fexceptions -g '
+ 'CONFIGURE_CFLAGS_NODIST': '-flto=auto -ffat-lto-objects -fexceptions -g '
                             '-grecord-gcc-switches -pipe -Wall '
                             '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                             '-Wp,-D_GLIBCXX_ASSERTIONS '
@@ -87,7 +86,7 @@ build_time_vars = {'ABIFLAGS': '',
                 "'--with-builtin-hashlib-hashes=blake2' '--with-valgrind' "
                 "'--without-ensurepip' '--enable-optimizations' "
                 "'build_alias=aarch64-redhat-linux-gnu' "
-                "'host_alias=aarch64-redhat-linux-gnu' 'CC=gcc' 'CFLAGS= -O2  "
+                "'host_alias=aarch64-redhat-linux-gnu' 'CC=gcc' 'CFLAGS=   "
                 '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
                 '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                 '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   '
@@ -653,7 +652,7 @@ build_time_vars = {'ABIFLAGS': '',
  'OPENSSL_INCLUDES': '',
  'OPENSSL_LDFLAGS': '',
  'OPENSSL_LIBS': '-lssl -lcrypto',
- 'OPT': '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG  -O2  -fexceptions -g '
+ 'OPT': '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG    -fexceptions -g '
         '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
         '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS  '
         '-fstack-protector-strong   -fasynchronous-unwind-tables '
@@ -691,7 +690,7 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"blake2"',
  'PY_BUILTIN_MODULE_CFLAGS': '-Wno-unused-result -Wsign-compare '
-                             '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG  -O2  '
+                             '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG    '
                              '-fexceptions -g -grecord-gcc-switches -pipe '
                              '-Wall -Werror=format-security '
                              '-Wp,-D_FORTIFY_SOURCE=2 '
@@ -699,21 +698,21 @@ build_time_vars = {'ABIFLAGS': '',
                              '-fstack-protector-strong   '
                              '-fasynchronous-unwind-tables '
                              '-fstack-clash-protection -D_GNU_SOURCE -fPIC '
-                             '-fwrapv -O2  -fexceptions -g '
-                             '-grecord-gcc-switches -pipe -Wall '
-                             '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
+                             '-fwrapv -fexceptions -g -grecord-gcc-switches '
+                             '-pipe -Wall -Werror=format-security '
+                             '-Wp,-D_FORTIFY_SOURCE=2 '
                              '-Wp,-D_GLIBCXX_ASSERTIONS  '
                              '-fstack-protector-strong   '
                              '-fasynchronous-unwind-tables '
                              '-fstack-clash-protection -D_GNU_SOURCE -fPIC '
-                             '-fwrapv  -O2  -fexceptions -g '
-                             '-grecord-gcc-switches -pipe -Wall '
-                             '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
+                             '-fwrapv    -fexceptions -g -grecord-gcc-switches '
+                             '-pipe -Wall -Werror=format-security '
+                             '-Wp,-D_FORTIFY_SOURCE=2 '
                              '-Wp,-D_GLIBCXX_ASSERTIONS  '
                              '-fstack-protector-strong   '
                              '-fasynchronous-unwind-tables '
                              '-fstack-clash-protection -D_GNU_SOURCE -fPIC '
-                             '-fwrapv -O2 -flto=auto -ffat-lto-objects '
+                             '-fwrapv  -O3 -flto=auto -ffat-lto-objects '
                              '-fexceptions -g -grecord-gcc-switches -pipe '
                              '-Wall -Werror=format-security '
                              '-Wp,-D_FORTIFY_SOURCE=2 '
@@ -729,38 +728,38 @@ build_time_vars = {'ABIFLAGS': '',
                              '-Wno-unused-result -Wno-unused-parameter '
                              '-Wno-missing-field-initializers '
                              '-Werror=implicit-function-declaration '
-                             '-fvisibility=hidden -O2 -flto=auto '
-                             '-ffat-lto-objects -fexceptions -g '
-                             '-grecord-gcc-switches -pipe -Wall '
-                             '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
+                             '-fvisibility=hidden -flto=auto -ffat-lto-objects '
+                             '-fexceptions -g -grecord-gcc-switches -pipe '
+                             '-Wall -Werror=format-security '
+                             '-Wp,-D_FORTIFY_SOURCE=2 '
                              '-Wp,-D_GLIBCXX_ASSERTIONS '
                              '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
                              '-fstack-protector-strong '
                              '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  '
                              '-fasynchronous-unwind-tables '
                              '-fstack-clash-protection -D_GNU_SOURCE -fPIC '
-                             '-fwrapv -fno-semantic-interposition  '
+                             '-fwrapv -fno-semantic-interposition -O3 '
                              '-fprofile-use -fprofile-correction '
                              '-I/builddir/build/BUILD/Python-3.9.19/Include/internal '
                              '-IObjects -IInclude -IPython -I. '
                              '-I/builddir/build/BUILD/Python-3.9.19/Include '
                              '-fPIC -DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare '
-              '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG  -O2  -fexceptions -g '
+              '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG    -fexceptions -g '
               '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
               '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS  '
               '-fstack-protector-strong   -fasynchronous-unwind-tables '
-              '-fstack-clash-protection -D_GNU_SOURCE -fPIC -fwrapv -O2  '
+              '-fstack-clash-protection -D_GNU_SOURCE -fPIC -fwrapv '
               '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
               '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
               '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   '
               '-fasynchronous-unwind-tables -fstack-clash-protection '
-              '-D_GNU_SOURCE -fPIC -fwrapv  -O2  -fexceptions -g '
+              '-D_GNU_SOURCE -fPIC -fwrapv    -fexceptions -g '
               '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
               '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS  '
               '-fstack-protector-strong   -fasynchronous-unwind-tables '
-              '-fstack-clash-protection -D_GNU_SOURCE -fPIC -fwrapv',
- 'PY_CFLAGS_NODIST': '-O2 -flto=auto -ffat-lto-objects -fexceptions -g '
+              '-fstack-clash-protection -D_GNU_SOURCE -fPIC -fwrapv  -O3',
+ 'PY_CFLAGS_NODIST': '-flto=auto -ffat-lto-objects -fexceptions -g '
                      '-grecord-gcc-switches -pipe -Wall '
                      '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                      '-Wp,-D_GLIBCXX_ASSERTIONS '
@@ -774,7 +773,7 @@ build_time_vars = {'ABIFLAGS': '',
                      '-Wno-unused-result -Wno-unused-parameter '
                      '-Wno-missing-field-initializers '
                      '-Werror=implicit-function-declaration '
-                     '-fvisibility=hidden -O2 -flto=auto -ffat-lto-objects '
+                     '-fvisibility=hidden -flto=auto -ffat-lto-objects '
                      '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
                      '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                      '-Wp,-D_GLIBCXX_ASSERTIONS '
@@ -782,26 +781,26 @@ build_time_vars = {'ABIFLAGS': '',
                      '-fstack-protector-strong '
                      '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  '
                      '-fasynchronous-unwind-tables -fstack-clash-protection '
-                     '-D_GNU_SOURCE -fPIC -fwrapv -fno-semantic-interposition  '
-                     '-fprofile-use -fprofile-correction '
+                     '-D_GNU_SOURCE -fPIC -fwrapv -fno-semantic-interposition '
+                     '-O3 -fprofile-use -fprofile-correction '
                      '-I/builddir/build/BUILD/Python-3.9.19/Include/internal',
  'PY_COERCE_C_LOCALE': 1,
  'PY_CORE_CFLAGS': '-Wno-unused-result -Wsign-compare '
-                   '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG  -O2  '
-                   '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
+                   '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG    -fexceptions '
+                   '-g -grecord-gcc-switches -pipe -Wall '
                    '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                    '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   '
                    '-fasynchronous-unwind-tables -fstack-clash-protection '
-                   '-D_GNU_SOURCE -fPIC -fwrapv -O2  -fexceptions -g '
+                   '-D_GNU_SOURCE -fPIC -fwrapv -fexceptions -g '
                    '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
                    '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS  '
                    '-fstack-protector-strong   -fasynchronous-unwind-tables '
-                   '-fstack-clash-protection -D_GNU_SOURCE -fPIC -fwrapv  -O2  '
+                   '-fstack-clash-protection -D_GNU_SOURCE -fPIC -fwrapv    '
                    '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
                    '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                    '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   '
                    '-fasynchronous-unwind-tables -fstack-clash-protection '
-                   '-D_GNU_SOURCE -fPIC -fwrapv -O2 -flto=auto '
+                   '-D_GNU_SOURCE -fPIC -fwrapv  -O3 -flto=auto '
                    '-ffat-lto-objects -fexceptions -g -grecord-gcc-switches '
                    '-pipe -Wall -Werror=format-security '
                    '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS '
@@ -815,15 +814,15 @@ build_time_vars = {'ABIFLAGS': '',
                    '-Wno-unused-result -Wno-unused-parameter '
                    '-Wno-missing-field-initializers '
                    '-Werror=implicit-function-declaration -fvisibility=hidden '
-                   '-O2 -flto=auto -ffat-lto-objects -fexceptions -g '
+                   '-flto=auto -ffat-lto-objects -fexceptions -g '
                    '-grecord-gcc-switches -pipe -Wall -Werror=format-security '
                    '-Wp,-D_FORTIFY_SOURCE=2 -Wp,-D_GLIBCXX_ASSERTIONS '
                    '-specs=/usr/lib/rpm/redhat/redhat-hardened-cc1 '
                    '-fstack-protector-strong '
                    '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  '
                    '-fasynchronous-unwind-tables -fstack-clash-protection '
-                   '-D_GNU_SOURCE -fPIC -fwrapv -fno-semantic-interposition  '
-                   '-fprofile-use -fprofile-correction '
+                   '-D_GNU_SOURCE -fPIC -fwrapv -fno-semantic-interposition '
+                   '-O3 -fprofile-use -fprofile-correction '
                    '-I/builddir/build/BUILD/Python-3.9.19/Include/internal '
                    '-IObjects -IInclude -IPython -I. '
                    '-I/builddir/build/BUILD/Python-3.9.19/Include -fPIC '
@@ -857,22 +856,22 @@ build_time_vars = {'ABIFLAGS': '',
  'PY_SSL_DEFAULT_CIPHERS': 2,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
  'PY_STDMODULE_CFLAGS': '-Wno-unused-result -Wsign-compare '
-                        '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG  -O2  '
+                        '-DDYNAMIC_ANNOTATIONS_ENABLED=1 -DNDEBUG    '
                         '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
                         '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                         '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   '
                         '-fasynchronous-unwind-tables -fstack-clash-protection '
-                        '-D_GNU_SOURCE -fPIC -fwrapv -O2  -fexceptions -g '
+                        '-D_GNU_SOURCE -fPIC -fwrapv -fexceptions -g '
                         '-grecord-gcc-switches -pipe -Wall '
                         '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                         '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   '
                         '-fasynchronous-unwind-tables -fstack-clash-protection '
-                        '-D_GNU_SOURCE -fPIC -fwrapv  -O2  -fexceptions -g '
+                        '-D_GNU_SOURCE -fPIC -fwrapv    -fexceptions -g '
                         '-grecord-gcc-switches -pipe -Wall '
                         '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                         '-Wp,-D_GLIBCXX_ASSERTIONS  -fstack-protector-strong   '
                         '-fasynchronous-unwind-tables -fstack-clash-protection '
-                        '-D_GNU_SOURCE -fPIC -fwrapv -O2 -flto=auto '
+                        '-D_GNU_SOURCE -fPIC -fwrapv  -O3 -flto=auto '
                         '-ffat-lto-objects -fexceptions -g '
                         '-grecord-gcc-switches -pipe -Wall '
                         '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
@@ -887,7 +886,7 @@ build_time_vars = {'ABIFLAGS': '',
                         '-Wextra -Wno-unused-result -Wno-unused-parameter '
                         '-Wno-missing-field-initializers '
                         '-Werror=implicit-function-declaration '
-                        '-fvisibility=hidden -O2 -flto=auto -ffat-lto-objects '
+                        '-fvisibility=hidden -flto=auto -ffat-lto-objects '
                         '-fexceptions -g -grecord-gcc-switches -pipe -Wall '
                         '-Werror=format-security -Wp,-D_FORTIFY_SOURCE=2 '
                         '-Wp,-D_GLIBCXX_ASSERTIONS '
@@ -896,7 +895,7 @@ build_time_vars = {'ABIFLAGS': '',
                         '-specs=/usr/lib/rpm/redhat/redhat-annobin-cc1  '
                         '-fasynchronous-unwind-tables -fstack-clash-protection '
                         '-D_GNU_SOURCE -fPIC -fwrapv '
-                        '-fno-semantic-interposition  -fprofile-use '
+                        '-fno-semantic-interposition -O3 -fprofile-use '
                         '-fprofile-correction '
                         '-I/builddir/build/BUILD/Python-3.9.19/Include/internal '
                         '-IObjects -IInclude -IPython -I. '
